Iowa Judicial Branch
Description: State of Iowa Official Judicial Branch Website

About the Courts
| Supreme Court
| Court of Appeals
| Court of Appeals Judges
| Court of Appeals Opinions
| Email Notification Service
| Recent Opinions
| Summaries for Most Recent Opinions
| Opinions Expected
| Opinions Archive
| 2014 Court Calendar
| Oral Argument Schedule
| Request for Speaker
| District Courts
| Juvenile Court
| Specialty Courts
| Small Claims Courts
| Jury Service
| Directories
| Advisory Committees
| You are here: Home » About the Courts » Court of Appeals » Court of Appeals Opinions |
Printable Version |
Iowa Court Of Appeals Opinions
July 16, 2014
NOTICE! Posting an opinion on this site DOES NOT constitute publication of the opinion. The opinions posted on this site are subject to modification or correction by the court. Opinions on this site are not to be considered final until the time for rehearing or further review has passed. The court of appeals publishes only a limited number of final opinions. An unpublished opinion of the Iowa appellate courts may be cited in a brief; however, unpublished opinions shall not constitute controlling legal authority. The official published opinions of the Iowa Court of Appeals are those published in the North Western Reporter published by West Group.
Opinions released before April 2006 and available in the archives are posted in Word format. Opinions released after April 2006 are posted to the website in PDF (Portable Document Format). Note: To open a PDF you must have the free Acrobat Reader installed. PDF format preserves the original appearance of a document without requiring you to possess the software that created that document. For more information about PDF read: Using the Adobe Reader.
For your convenience, the Judicial Branch offers a free e-mail notification service for Supreme Court opinions, Court of Appeals opinions, press releases and orders. To subscribe, click here.
NOTE: Copies of these opinions may be obtained from the Clerk of the Supreme Court, Judicial Branch Building, 1111 East Court Avenue, Des Moines, IA 50319, for a fee of fifty cents per page.
Summaries of most recent opinions.
No. 3-1256 / 13-0981
STATE OF IOWA, Plaintiff-Appellee, vs. CHAD JAY ROUSE, Defendant-Appellant.
No. 4-054 / 13-0916
STATE OF IOWA, Plaintiff-Appellee, vs. TODD CARBER, Defendant-Appellant.
No. 11-1946
STATE OF IOWA, Plaintiff-Appellee, vs. RACHEL ELIZABETH CLAY, Defendant-Appellant.
No. 12-1810
CARL GENE GARNICA, Applicant-Appellant, vs. STATE OF IOWA, Respondent-Appellee.
No. 12-1925
STATE OF IOWA, Plaintiff-Appellee, vs. RAYMOND DEAN COOPER, Defendant-Appellant.
No. 12-2122
STATE OF IOWA, Plaintiff-Appellee, vs. MARIO GUERRERO CORDERO, Defendant-Appellant.
No. 12-2204
DONNO SHANE ZEKUCIA, Plaintiff-Appellant, vs. MARIA ISABEL JOHNSON n/k/a MARIA ISABEL PETERSON, Defendant-Appellee/Cross-Appellant.
No. 13-0201
ALVIN WORKMAN, Applicant-Appellant, vs. STATE OF IOWA, Respondent-Appellee.
No. 13-0244
ANTHONY BROWN, Applicant-Appellant, vs. STATE OF IOWA, Respondent-Appellee.
No. 13-0291
DOUGLAS E. KURTZ, Applicant-Appellant, vs. STATE OF IOWA, Respondent-Appellee.
No.13-0298
DANA PETERSON, Petitioner-Appellant, vs. IOWA DEPARTMENT OF HUMAN SERVICES, Respondent-Appellee.
No. 13-0522
STATE OF IOWA, Plaintiff-Appellee, vs. DENNIS EARL LEAHY, Defendant-Appellant.
No. 13-0524
STATE OF IOWA, Plaintiff-Appellee, vs. MARTIN LEON MORALES, Defendant-Appellant.
No. 13-0755
RUSS HOTCHKISS and DARUSS ENTERPRISES, INC., d/b/a PROSHIELD FIRE PROTECTION, an Iowa Corporation, Plaintiffs-Appellants, vs. INTERNATIONAL PROFIT ASSOCIATES, INC., n/k/a INTERNATIONAL SERVICES, INC., an Illinois Corporation, INTERNATIONAL TAX ADVISORS, INC., n/k/a STRATEGIC TAX ADVISORS, INC., a Nevada Corporation, and ACCOUNTANCY ASSOCIATES, LLC, n/k/a VALUATION ADVISORY SERVICES, LLC, an Illinois Limited Liability Co., Defendants-Appellees.
No. 13-0794
STATE OF IOWA, Plaintiff-Appellee, vs. WARREN EDWARD PURVIS, Defendant-Appellant.
No. 13-0840
FRANK D. BOURRAGE, Applicant-Appellant, vs. STATE OF IOWA, Respondent-Appellee.
No. 13-0859
NORTH GLENN HOMEOWNERS ASSOCIATION, Plaintiff-Appellee, vs. STATE FARM FIRE & CASUALTY COMPANY, Defendant-Appellant.
No. 13-0958
TERRY HARRIS, Applicant-Appellant, vs. STATE OF IOWA, Respondent-Appellee.
No. 13-0976
STATE OF IOWA, Plaintiff-Appellee, vs. ERROLL ANTOINE TAYLOR, Defendant-Appellant.
No. 13-0993
STATE OF IOWA, Plaintiff-Appellee, vs. JAMERIOUS LANIER SMITH, Defendant-Appellant.
No. 13-0998
JACQUE LOUIS MILLER, Applicant-Appellant, vs. STATE OF IOWA, Respondent-Appellee.
No. 13-1028
STATE OF IOWA, Plaintiff-Appellee, vs. DEANDRE GOODE, Defendant-Appellant.
No. 13-1103
STATE OF IOWA, Plaintiff-Appellee, vs. SHAUNTA HOPKINS, Defendant-Appellant.
No. 13-1113
STATE OF IOWA, Plaintiff-Appellee, vs. JILLIAN JANE STEWART, Defendant-Appellant.
No. 13-1165
WALTER JUNIOR HOSKINS, III, Applicant-Appellant, vs. STATE OF IOWA, Respondent-Appellee.
No. 13-1170
IN THE MATTER OF THE ESTATE OF OWEETIS FRYE, Deceased. ROBERT D. FRYE, BENJAMIN D. FRYE, and HANNA M. FRYE, Beneficiaries-Appellants.
No. 13-1200
STATE OF IOWA, Plaintiff-Appellee, vs. CORNELL A. FIELDS, Defendant-Appellant.
No. 13-1206
STATE OF IOWA, Plaintiff-Appellee, vs. BOBBY JOE MADSEN JR., Defendant-Appellant.
No. 13-1208
GRINNELL STATE BANK, Plaintiff-Appellee, vs. PARTIES IN POSSESSION, Defendants, and SUZANNE K. STEPHENSON, Defendant-Appellant.
No. 13-1218
STATE OF IOWA, Plaintiff-Appellee, vs. JAMES R. THIELMAN, Defendant-Appellant.
No. 13-1223
STATE OF IOWA, Plaintiff-Appellee, vs. RONALD E. VOWELS JR., Defendant-Appellant.
No. 13-1242
BRYAN BOYD, Plaintiff-Appellant, vs. LEGISLATIVE SERVICES AGENCY, GLEN DICKINSON and STATE OF IOWA, Defendant-Appellees.
No. 13-1251
STATE OF IOWA, Plaintiff-Appellee, vs. FAITH DAYLENE LOHR, Defendant-Appellant.
No. 13-1301
STATE OF IOWA, Plaintiff-Appellee, vs. ISAIAH JOSHUA ALEXANDER, Defendant-Appellant.
No. 13-1358
MEDICAL ASSOCIATES OF CLINTON, P.L.C., Plaintiff-Appellant, vs. CHRISTOPHER S.E. MARTIN, M.D., Defendant-Appellee.
No. 13-1390
IN RE THE MARRIAGE OF JOHN MINEART AND TAMI JO MINEART Upon the Petition of JOHN MINEART, Petitioner-Appellant, And Concerning TAMI JO MINEART, Respondent-Appellee.
No. 13-1396
STATE OF IOWA, Plaintiff-Appellee, vs. KRIS WARICK, Defendant-Appellant.
No. 13-1418
IN THE INTEREST OF A.S. JR., Minor Child, E.W., Mother, Appellant, A.S. SR., Father, Appellant.
No. 13-1426
IN RE THE MARRIAGE OF ADREANNE MARIE GRAVES AND DAVID EDWARD GRAVES Upon the Petition of ADREANNE MARIE GRAVES, Petitioner-Appellant, And Concerning DAVID EDWARD GRAVES, Respondent-Appellee.
No.13-1462
IN RE THE MARRIAGE OF NICOLE CLEVERINGA AND DARIN L. CLEVERINGA Upon the Petition of NICOLE CLEVERINGA, Petitioner-Appellant, And Concerning DARIN L. CLEVERINGA, Respondent-Appellee.
No. 13-1469
STATE OF IOWA, Plaintiff-Appellee, vs. CLIFFORD ORRIS JACKSON JR., Defendant-Appellant.
No. 13-1490
STATE OF IOWA, Plaintiff-Appellee, vs. DANIEL E. MORRISSEY, Defendant-Appellant.
No. 13-1559
ROBERT O. DAVIS, Plaintiff-Appellant, vs. CLIFFORD GARTH DAVIS, CONNIE SUE WORKMAN, and JAMES CRAIG DAVIS, Defendants-Appellees.
No. 13-1562
IN RE THE MARRIAGE OF TRAVIS R. DUGGAN AND DANIELLE L. DUGGAN Upon the Petition of TRAVIS R. DUGGAN, Petitioner-Appellant, And Concerning DANIELLE L. DUGGAN, Respondent-Appellee.
No. 13-1574
STATE OF IOWA, Plaintiff-Appellee, vs. CHAD RYAN TANNAHILL, Defendant-Appellant.
No. 13-1653
ARCHITECTURAL WALL SYSTEMS and ZURICH NORTH AMERICA, Petitioners-Appellants, vs. DONALD TOWERS, Respondent-Appellee.
No. 13-1757
IN RE THE MARRIAGE OF TRACY LYNN HOFFMAN AND ERNST FRANKLIN HOFFMAN Upon the Petition of TRACY LYNN HOFFMAN, Petitioner-Appellant, And Concerning ERNST FRANKLIN HOFFMAN, Respondent-Appellee.
No. 13-1784
STATE OF IOWA, Plaintiff-Appellant, vs. ALEXANDER M. OPONSKI-SIMS, Defendant-Appellee.
No. 13-1811
ACTUALLY CLEAN FLOOR & FURNITURE, L.L.C., Assignee of JASON BAILEY, Plaintiff-Appellant, vs. ACTION RESTORATION, INC., Defendant-Appellee.
No. 13-1826
STATE OF IOWA, Plaintiff-Appellee, vs. RENEE ROCHELLE OPPERUD, Defendant-Appellant.
No. 13-1834
STATE OF IOWA, Plaintiff-Appellee, vs. REX DEAN MCDERMOTT, Defendant-Appellant.
No. 13-1889
IN RE THE MARRIAGE OF DAREN LEE LAURITSEN AND DANA MARIE LAURITSEN Upon the Petition of DAREN LEE LAURITSEN, Petitioner-Appellee, And Concerning DANA MARIE LAURITSEN, Respondent-Appellant.
No. 13-1988
JANENE M. GORSETT, Plaintiff-Appellee, vs. JAMES PATRICK GENGLER, Defendant-Appellant.
No. 13-2003
STATE OF IOWA, Plaintiff-Appellee, vs. NICHOLAS PAUL AUGUSTINE, Defendant-Appellant.
No. 14-0096
IN RE THE MATTER OF S.L., Alleged to Be Seriously Mentally Impaired, S.L., Respondent-Appellant.
No. 14-0133
IN RE THE MARRIAGE OF PAUL A. STEPHENS AND NICHOLE R. STEPHENS Upon the Petition of PAUL A. STEPHENS, Petitioner-Appellee, And Concerning NICHOLE R. STEPHENS, Respondent-Appellant.
No. 14-0333
IN THE INTEREST OF J.L.-S. and C.L.-S., Minor Children, A.S., Mother, Appellant.
No. 14-0445
IN THE INTEREST OF D.D., K.D., AND K.M., Minor Children, C.M., Mother, Appellant, J.D., Father, Appellant.
No. 14-0592
IN THE INTEREST OF A.C. AND A.J., Minor Children, J.C., Father, Appellant.
No. 14-0610
IN THE INTEREST OF D.S., Minor Child, D.S., Father, Appellant.
No. 14-0658
IN THE INTEREST OF J.C., Minor Child, K.C., Mother, Appellant.
No. 14-0673
IN THE INTEREST OF J.P., Minor Child, L.P., Mother, Appellant.
No. 14-0704
IN THE INTEREST OF C.B., Minor Child, S.B., Mother, Appellant.
No. 14-0706
IN THE INTEREST OF T.E., Minor Child, G.W., Father, Appellant.
No. 14-0708
IN THE INTEREST OF H.L., Minor Child, A.L., Father, Appellant.
No. 14-0714
IN THE INTEREST OF N.T., Minor Child, M.T., Father, Appellant, K.W., Mother, Appellant.
No. 14-0753
IN THE INTEREST OF K.M. and J.M. JR., Minor Children, A.M., Mother, Appellant, J.M. SR., Father, Appellant.
No. 14-0754
IN THE INTEREST OF E.C., A.C. G.N., J.N., and A.N., Minor Children, J.N., Father, Appellant, B.M., Mother, Appellant.
No. 14-0805
IN THE INTEREST OF R.L.P. AND R.M.P., Minor Children, C.P., Mother, Appellant.
No. 14-0808
IN THE INTEREST OF C.P. and K.P., Minor Children, J.P., Father, Appellant.
No. 13-0966
MICHAEL EUGENE HORLAS, Applicant-Appellant, vs. STATE OF IOWA, Respondent-Appellee.

| return to top

Directories | ADA Access | Site Tools | Site Map | Privacy Policy | Contact Us Copyright © 2014 Iowa Judicial Branch